#!/bin/bash
#remove (r. COL or r. SAL) and h.
PDB=`ls *_deprot_neutral.pdb`
PROT=`basename $PDB _deprot_neutral.pdb`
echo $PDB

module add ambertools/21
export LC_NUMERIC="en_US.UTF-8"

# solvate the system by adding required ions after loading required parameters and finally neutralize 
cat > tleap.inp << EOF
source leaprc.protein.ff19SB
source leaprc.gaff2
source leaprc.water.opc
loadoff parms/heme.lib
loadamberparams parms/heme.frcmod
loadamberparams parms/mcpbpy.frcmod
loadoff parms/choline_RESP.lib
loadamberparams parms/choline.frcmod
loadoff parms/salicylate_RESP.lib
loadamberparams parms/salicylate.frcmod
loadoff parms/ATP.lib
loadamberparams parms/frcmod.phos

protein = loadpdb ${PDB}
bond protein.80.CA protein.107.CB1
bond protein.18.CA protein.107.CB 
bond protein.105.CA protein.107.C2A
bond protein.106.CA protein.107.C3D
setbox protein vdw 0
check protein
saveamberparm protein ${PROT}.parm7 ${PROT}.inpcrd
savepdb protein ${PROT}_tleap.pdb
quit
EOF

tleap -f tleap.inp &> tleap.out

# perform hydrogen mass repartitioning
cat > parmed.inp << EOF
HMassRepartition
parmout ${PROT}_HMR.parm7
go
EOF
parmed -O -p ${PROT}.parm7 -i parmed.inp &> parmed.out

exit 0
